import { SecretValue } from 'aws-cdk-lib';
import { IGrantable } from 'aws-cdk-lib/aws-iam';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { SingletonFunction } from 'aws-cdk-lib/aws-lambda';
import { ISecret } from 'aws-cdk-lib/aws-secretsmanager';
import { Construct } from 'constructs';
export declare enum UploadType {
    /**
     * Pass the secret data inline (base64 encoded and compressed)
     */
    INLINE = "INLINE",
    /**
     * Uplaod the secert data as asset
     */
    ASSET = "ASSET"
}
export declare enum CreationType {
    /**
     * Create or update a single secret/parameter
     */
    SINGLE = "SINGLE",
    /**
     * Create or update a multiple secrets/parameters by flattening the SOPS file
     */
    MULTI = "MULTI"
}
export declare enum ResourceType {
    SECRET = "SECRET",
    PARAMETER = "PARAMETER"
}
/**
 * Configuration options for the SopsSync
 */
export interface SopsSyncOptions {
    /**
     * The custom resource provider to use. If you don't specify any, a new
     * provider will be created - or if already exists within this stack - reused.
     *
     * @default - A new singleton provider will be created
     */
    readonly sopsProvider?: SopsSyncProvider;
    /**
     * The filepath to the sops file
     */
    readonly sopsFilePath?: string;
    /**
     * If you want to pass the sops file via s3, you can specify the bucket
     * you can use cfn parameter here
     * Both, sopsS3Bucket and sopsS3Key have to be specified
     */
    readonly sopsS3Bucket?: string;
    /**
     * If you want to pass the sops file via s3, you can specify the key inside the bucket
     * you can use cfn parameter here
     * Both, sopsS3Bucket and sopsS3Key have to be specified
     */
    readonly sopsS3Key?: string;
    /**
     * How should the secret be passed to the CustomResource?
     * @default INLINE
     */
    readonly uploadType?: UploadType;
    /**
     * The format of the sops file.
     *
     * @default - The fileformat will be derived from the file ending
     */
    readonly sopsFileFormat?: undefined | 'json' | 'yaml' | 'dotenv' | 'binary';
    /**
     * The kmsKey used to encrypt the sops file. Encrypt permissions
     * will be granted to the custom resource provider.
     *
     * @default - The key will be derived from the sops file
     */
    readonly sopsKmsKey?: IKey[];
    /**
     * The age key that should be used for encryption.
     */
    readonly sopsAgeKey?: SecretValue;
    /**
     * Should the encrypted sops value should be converted to JSON?
     * Only JSON can be handled by cloud formations dynamic references.
     *
     * @default true
     */
    readonly convertToJSON?: boolean;
    /**
     * Should the structure be flattened? The result will be a flat structure and all
     * object keys will be replaced with the full jsonpath as key.
     * This is usefull for dynamic references, as those don't support nested objects.
     *
     * @default true
     */
    readonly flatten?: boolean;
    /**
     * If the structure should be flattened use the provided separator between keys.
     *
     * @default '.'
     */
    readonly flattenSeparator?: string;
    /**
     * Add this prefix to parameter names.
     */
    readonly parameterKeyPrefix?: string;
    /**
     * Shall all values be flattened? This is usefull for dynamic references, as there
     * are lookup errors for certain float types
     */
    readonly stringifyValues?: boolean;
    readonly creationType?: CreationType;
    readonly resourceType?: ResourceType;
}
/**
 * The configuration options extended by the target Secret
 */
export interface SopsSyncProps extends SopsSyncOptions {
    /**
     * The secret that will be populated with the encrypted sops file content.
     */
    readonly secret?: ISecret;
    /**
     * The parameter name. If set this creates an encrypted SSM Parameter instead of a secret.
     */
    readonly parameterName?: string;
    /**
     * The parameter name. If set this creates an encrypted SSM Parameter instead of a secret.
     */
    readonly parameterNames?: string[];
    /**
     * The encryption key used for encrypting the ssm parameter if `parameterName` is set.
     */
    readonly encryptionKey?: IKey;
}
export declare class SopsSyncProvider extends SingletonFunction implements IGrantable {
    private sopsAgeKeys;
    constructor(scope: Construct, id?: string);
    addAgeKey(key: SecretValue): void;
}
/**
 * The custom resource, that is syncing the content from a sops file to a secret.
 */
export declare class SopsSync extends Construct {
    /**
     * The current versionId of the secret populated via this resource
     */
    readonly versionId: string;
    /**
     * Was the format converted to json?
     */
    readonly converToJSON: boolean;
    /**
     * Was the structure flattened?
     */
    readonly flatten: boolean;
    /**
     * Were the values stringified?
     */
    readonly stringifiedValues: boolean;
    constructor(scope: Construct, id: string, props: SopsSyncProps);
    private createReducedParameterPolicy;
}
